@@ -84,7 +84,7 @@ def combineResults(allout):
 
 @task()
 def AnalyzeSpeaker(speaker,form):
-    return speaker.analyze(form)
+    #return speaker.analyze(form)
     out = speaker.analyze(form)
     with open(fetch_media_resource("Results/Buckeye/"+str(speaker)+".txt"),'w') as f:
         f.write("\t".join(out[0].keys()))
@@ -102,9 +102,9 @@ def doBasicAnalysis(form):
     else:
         #for s in sp:
         #    AnalyzeSpeaker.delay(s,form)
-        job = group([AnalyzeSpeaker.subtask(s, form) for s in sp])
-        job.apply_async(link=consolidateResultFiles.s())
-        #res = chord((AnalyzeSpeaker.s(s, form) for s in sp), combineResults.s())()
+        #job = group([AnalyzeSpeaker.s(speaker, form) for speaker in sp])
+        #job.apply_async(link=consolidateResultFiles.s())
+        res = chord((AnalyzeSpeaker.s(s, form) for s in sp), consolidateResultFiles.s())
 
 @task()
 def consolidateResultFiles():
@@ -113,8 +113,11 @@ def consolidateResultFiles():
     with open(fetch_buckeye_resource("Results/Buckeye/allresults.txt"),'w') as allout:
         for fn in outs:
             with open(fetch_buckeye_resource("Results/Buckeye/%s"%fn),'r') as f:
+                curhead = False
                 for l in f:
                     if not head:
-                        allout.write(l)
                         head = True
-                    f.write(l)
+                    elif not curhead:
+                        curhead = True
+                        continue
+                    allout.write(l)
