@@ -7,6 +7,7 @@ import os
 
 from django.conf import settings
 
+from .helper import loadFile
 
 def get_dist():
     from django.db import connection
@@ -34,19 +35,6 @@ Group by StressVowel,buckeyebrowser_speaker.Number""")
     return dist
 
 
-def loadFile(path,cols=None):
-    head = None
-    with open(path,'r') as f:
-        lines = []
-        for l in f:
-            if head is None:
-                head = l.strip().split("\t")
-                continue
-            line = l.strip().split("\t")
-            newline = { h: line[i] for i,h in enumerate(head) if cols is None or h in cols}
-            lines.append(newline)
-    return lines
-
 def get_outliers(filename):
     dist = get_dist()
     outs = loadFile(filename,cols=['Token','Word','Speaker','Vowel','F1','F2'])
@@ -70,14 +58,6 @@ def get_outliers(filename):
             outliers.append(o)
     return outliers
 
-def fetch_buckeye_resource(uri):
-    path = os.path.join(settings.BUCKEYE_ROOT,uri)
-    return path
-
-def fetch_media_resource(uri):
-    path = os.path.join(settings.MEDIA_ROOT,uri)
-    return path
-
 
 
 
